==> qcloudcli-1.0.zip: qcloudcli-1.0/qcloudsdkcvm/DescribeInstancesRequest.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-

from qcloudsdkcore.request import Request
class DescribeInstancesRequest(Request):

    def __init__(self):
        Request.__init__(self, 'CVM', 'SDK_PYTHON_1.1', 'DescribeInstances', 'cvm.api.qcloud.com')

    def get_instanceIds(self):
        return self.get_params().get('instanceIds')

    def set_instanceIds(self, instanceIds):
        self.add_param('instanceIds', instanceIds)

    def get_status(self):
        return self.get_params().get('status')

    def set_status(self, status):
        self.add_param('status', status)

    def get_lanIps(self):
        return self.get_params().get('lanIps')

    def set_lanIps(self, lanIps):
        self.add_param('lanIps', lanIps)

    def get_searchWord(self):
        return self.get_params().get('searchWord')

    def set_searchWord(self, searchWord):
        self.add_param('searchWord', searchWord)
		
    def get_projectId(self):
        return self.get_params().get('projectId')

    def set_projectId(self, projectId):
        self.add_param('projectId', projectId)
		
    def get_zoneId(self):
        return self.get_params().get('zoneId')

    def set_zoneId(self, zoneId):
        self.add_param('zoneId', zoneId)

    def get_offset(self):
        return self.get_params().get('offset')

    def set_offset(self, offset):
        self.add_param('offset', offset)
		
    def get_limit(self):
        return self.get_params().get('limit')

    def set_limit(self, limit):
        self.add_param('limit', limit)

==> qcloudcli-1.4.zip: qcloudcli-1.4/qcloudsdkcvm/DescribeInstancesRequest.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-

from qcloudsdkcore.request import Request
class DescribeInstancesRequest(Request):

    def __init__(self):
        Request.__init__(self, 'CVM', 'qcloudcliV1', 'DescribeInstances', 'cvm.api.qcloud.com')

    def get_instanceIds(self):
        return self.get_params().get('instanceIds')

    def set_instanceIds(self, instanceIds):
        self.add_param('instanceIds', instanceIds)

    def get_status(self):
        return self.get_params().get('status')

    def set_status(self, status):
        self.add_param('status', status)

    def get_lanIps(self):
        return self.get_params().get('lanIps')

    def set_lanIps(self, lanIps):
        self.add_param('lanIps', lanIps)

    def get_searchWord(self):
        return self.get_params().get('searchWord')

    def set_searchWord(self, searchWord):
        self.add_param('searchWord', searchWord)
		
    def get_projectId(self):
        return self.get_params().get('projectId')

    def set_projectId(self, projectId):
        self.add_param('projectId', projectId)
		
    def get_zoneId(self):
        return self.get_params().get('zoneId')

    def set_zoneId(self, zoneId):
        self.add_param('zoneId', zoneId)

    def get_offset(self):
        return self.get_params().get('offset')

    def set_offset(self, offset):
        self.add_param('offset', offset)
		
    def get_limit(self):
        return self.get_params().get('limit')

    def set_limit(self, limit):
        self.add_param('limit', limit)
